#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# ----------------------------------------------------------------------------------------------------------------------
# Author: Lalith Kumar Shiyam Sundar | Aaron Selfridge
# Institution: Medical University of Vienna | University of California, Davis
# Research Group: Quantitative Imaging and Medical Physics (QIMP) Team | EXPLORER Molecular Imaging Center
# Date: 09.02.2023
# Version: 0.1.0
#
# Description:
# The display module of nifti2dicom. This module contains the display messages for nifti2dicom.
# ----------------------------------------------------------------------------------------------------------------------


import pyfiglet
from nifti2dicom import constants


def display_welcome_message():
    """
    Displays the welcome message.
    :return:
    """
    logo_color_code = constants.ANSI_VIOLET
    print(' ')
    result = logo_color_code + pyfiglet.figlet_format('nifti2dicom', font='slant').rstrip()  + constants.ANSI_RESET
    text = (logo_color_code + 'A package to convert NIfTI images to DICOM format using a reference DICOM series. '
                              'Nifti2dicom is a part of the ENHANCE.PET (https://enhance.pet) framework' +
            constants.ANSI_RESET)

    print(result)
    print(text)
    print(' ')





#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# ----------------------------------------------------------------------------------------------------------------------
# Author: Lalith Kumar Shiyam Sundar
# Institution: Medical University of Vienna
# Research Group: Quantitative Imaging and Medical Physics (QIMP) Team
# Date: 09.02.2023
# Version: 2.0.0
#
# Description:
# The main module of nifti2dicom. This module contains the main function that is executed when nifti2dicom is run.
# ----------------------------------------------------------------------------------------------------------------------


# COLOR CODES
ANSI_ORANGE = '\033[38;5;208m'
ANSI_GREEN = '\033[38;5;40m'
ANSI_VIOLET = '\033[38;5;141m'
ANSI_RESET = '\033[0m'


TAGS_TO_EXCLUDE = ["Pixel Data", "Image Index", "Number of Slices", "Rows", "Columns", 'Pixel Spacing',
                   "Image Position (Patient)", "Image Orientation (Patient)", "Instance Number", "Slice Thickness",
                   "Slice Location"]




from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='nifti2dicom',
    version='1.2.5',
    packages=find_packages(),
    install_requires=[
        'nibabel',
        'numpy',
        'emoji',
        'rich',
        'pydicom<3.0',
        'highdicom',
        'pyfiglet'
    ],
    entry_points={
        'console_scripts': [
            'nifti2dicom=nifti2dicom.converter:main',
        ],
    },
    author='Lalith Kumar Shiyam Sundar',
    description='A package to convert NIfTI images to DICOM format using a reference DICOM series.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    license='MIT',
    keywords='nifti dicom converter',
)
